@@ -6,8 +6,9 @@ use Carp;
 attr 'router' => sub { croak 'router is required' };
 attr 'parent' => sub { croak 'parent is required' };
 
-sub add {
-    my ( $self, $pattern, $descr, $parent_data ) = @_;
+sub add
+{
+    my ($self, $pattern, $descr, $parent_data) = @_;
     my $parent = $self->parent;
 
     croak "Cannot chain 'add' calls because the parent route was not parsed correctly"
@@ -21,7 +22,7 @@ sub add {
 
     # parent is a bridge now (even if the add call fails)
     $parent->bridge(1);
-    return $self->router->add( $pattern, $descr, $parent_data );
+    return $self->router->add($pattern, $descr, $parent_data);
 }
 
 1;
